checkRequire("Lua_CommonFlashCardItem");
Lua_CollectionBookEditWindow = class("Lua_CollectionBookEditWindow", Lua_Window);
function Lua_CollectionBookEditWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER
	self.windowName = "Lua_CollectionBookEditWindow";
	self.skinName = "CollectionWeaponEditWindow_skin";
	self.isFullSizeWin = true;
	self.showBlackMask = true;
	self.showWinBg = true;
	self.winBgPath = "/images/collect_book/xui_scc_bg_1.jpg";
    self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_CollectionBookEditWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.hasCardCount = 0;
	self.cardList = Lua_DragList.new(self.content, 636, 330 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.cardList:setListCell(Lua_CollectionWeaponEditCardItem, 144, 176, 4);
    self.cardList:setRectAnchor(7);
    self.cardList:setRectPivot(7)
    self.cardList:setLocation( -2, 146, 0);
    self.cardList:setCellSpacing(23, 24);

    self.cardListBg:SetDimensions(720, self.adaptHeight + 401);
	self:createPageCards(); 
	self:updateCardList(true);
	self.canelBtnSp:addClickFuntion(self, self.hide);
	self.saveBtnSp:addClickFuntion(self, self.onClickSaveBtn);

	self:addLuaEvent("COLLECTBOOK_CANCEL_PAGECARD", self, self.cancelPageCard); --取消封面卡牌
	self:addLuaEvent("COLLECTBOOK_UPDATE_PAGECARD", self, self.updatePageCard); --更新封面卡牌
end

function Lua_CollectionBookEditWindow:onScreenResize()
	self:superCall("onScreenResize");
	self.cardList:setContentRect(636, 330 + self.adaptHeight);
	self.cardListBg:SetDimensions(720, self.adaptHeight + 401);
end

function Lua_CollectionBookEditWindow:dispose()
	if self.cardList ~= nil then
		self.cardList:dispose();
		self.cardList = nil;
	end
	if self.pageCardList ~= nil then
		for i = 1, #self.pageCardList do
			self.pageCardList[i]:dispose();
			self.pageCardList[i] = nil;
		end
		self.pageCardList = nil;
	end
	DataCenter.collectionBookData:clearPageEditData();
	self:superCall("dispose");
end

-- 创建封面卡牌
function Lua_CollectionBookEditWindow:createPageCards()
	local id;
	local item;
	local list = DataCenter.collectionBookData:getPageEditIds();
	for i = 1, #list do
		id = list[i];
		item = self:getItemByIndex(i);
		item:setData(id, i);
	end
end

function Lua_CollectionBookEditWindow:getItemByIndex(index)
	if self.pageCardList == nil then
		self.pageCardList = {};
	end

	local item = self.pageCardList[index];
	if item == nil then
		item = Lua_CollectionWeaponEditItem.new(self.content);
		item:setRectAnchor(1);
		self.pageCardList[index] = item;
	end

	return item;
end

function Lua_CollectionBookEditWindow:updateCardList(isMove)
	local list = DataCenter.collectionBookData.activePushIdBagIds;
	self.hasCardCount = #list;
	self.cardList:setArrayData(list);
	self.noneCardSp:setEnable(self.hasCardCount == 0);
	self.noneCardTxt:setEnable(self.hasCardCount == 0);
	if isMove then
		self.cardList:moveToIndex(1, true);
	end
end

function Lua_CollectionBookEditWindow:updatePageCard(index)
	local cardId = DataCenter.collectionBookData:getEditCardIdByIndex(index);
	self.pageCardList[index]:setData(cardId, index);
end

function Lua_CollectionBookEditWindow:cancelPageCard(param)
	DataCenter.collectionBookData:setPageEditId(param, 0);
	self:updatePageCard(param);
	self:updateCardList();
end

function Lua_CollectionBookEditWindow:onClickSaveBtn()
	local pageCount = 0;
	local list = DataCenter.collectionBookData:getPageEditIds();
	local limitCount = DataCenter.collectionBookUtil.CBMaxCount;
	for i = 1, #list do
		if list[i] > 0 then
			pageCount = pageCount + 1;
		end 
	end

	if pageCount == limitCount or self.hasCardCount < limitCount then
		self:onSureFun();
	else
        local tipsData = { des = LanUtil.getValue(410017), btnType = 1, owner = self, sureFun = self.onSureFun };
        Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
	end
end

function Lua_CollectionBookEditWindow:onSureFun()
	Lua_ProxyManager.getProxy("Lua_CollectionBookProxy"):sSaveCBPageInfo(DataCenter.collectionBookData:getPageEditIds());
	self:hide();
end







































--------------------------------------------------------------------------------------------------------
-- 编辑收藏册卡牌
Lua_CollectionWeaponEditCardItem = class("Lua_CollectionWeaponEditCardItem", Lua_ListCell);
function Lua_CollectionWeaponEditCardItem:ctor(p)
    self:superCall("ctor", p, "CollectionWeaponEditCardItem_skin");
end

function Lua_CollectionWeaponEditCardItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_CollectionWeaponEditCardItem:setData(data)
	self.data = data;
	self.pushId = nil;
	self.bSelected = nil;
	if self.data == nil then
		return;
	end

	local vo = DataCenter.collectionBookData:getCollectionBookVoById(self.data);
	if vo == nil then
		return;
	end

	self.pushId = vo.pushId;
	if vo:checkActiveByCardId(self.pushId) ~= true then
		self.nameTxt.text = nil;
		return;
	end

	local cfg = Lua_CollectionBookConfigData.getConfig(self.pushId);
	local flashInfo = Lua_FlashCardConfigData.getConfig(cfg.flash_id);
	self.cardIcon:setUrl(flashInfo.flash_path_2);
	self.nameTxt.text = flashInfo.flash_card_name;
	self.bSelected = DataCenter.collectionBookData:getEditBSelectedById(self.pushId) ~= nil;
	self.isSelectedSp:setEnable(self.bSelected);
end

function Lua_CollectionWeaponEditCardItem:onPressClick()
	if self.bSelected then
		local index = DataCenter.collectionBookData:getEditBSelectedById(self.pushId);
		DataCenter.collectionBookData:setPageEditId(index, 0);
		Lua_MsgUtil.callFunc("COLLECTBOOK_UPDATE_PAGECARD", index);
	else
		local id;
		local index;
		local list = DataCenter.collectionBookData:getPageEditIds();
		for i = 1, #list do
			id = list[i];
			if id <= 0 then
				index = i;
				break;
			end
		end

		if index == nil then
			OperateAlert.showLangValue(410019);
			return;
		end

		DataCenter.collectionBookData:setPageEditId(index, self.pushId);
		Lua_MsgUtil.callFunc("COLLECTBOOK_UPDATE_PAGECARD", index);
	end

	self.bSelected = not self.bSelected;
	self.isSelectedSp:setEnable(self.bSelected);
end

function Lua_CollectionWeaponEditCardItem:dispose()
	self:superCall("dispose");
end
























--------------------------------------------------------------------------------------------------------
-- 编辑收藏册《封面》卡牌
Lua_CollectionWeaponEditItem = class("Lua_CollectionWeaponEditItem", Lua_DisplayObject);
function Lua_CollectionWeaponEditItem:ctor(p)
    self:superCall("ctor", p);
end

function Lua_CollectionWeaponEditItem:buildShowItem()
	self:superCall("buildShowItem");

	self.flashItem = Lua_CommonFlashCardItem.new(self.content);
	self.flashItem.canRotate = false; -- 是否可旋转
	self.flashItem:setScale(0.26, 0.26);
	self.flashItem:setCallBack(self, self.onPressClick);
end

function Lua_CollectionWeaponEditItem:updateDisplay(index, bNewCard)
	local posX, posY, sibling, scale;
	if index == 1 then
		sibling = 9;
		posX, posY = -136,  -596;
		scale = bNewCard and 0.82 * 0.48 or 0.82 * 0.64;
	elseif index == 2 then
		sibling = 11;
		posX, posY =  111,  -461;
		scale = bNewCard and 0.82 * 0.28 or 0.82 * 0.38;
	elseif index == 3 then
		sibling = 13;
		posX, posY =  145,  -715;
		scale = bNewCard and 0.82 * 0.28 or 0.82 * 0.38;
	end

	self:setLocation(posX, posY);
	self:setSiblingIndex(sibling);
	self.flashItem:setScale(scale, scale);
end

function Lua_CollectionWeaponEditItem:setData(data, index)
	self.data = data;
	self.index = index;
	if index == nil then
		return;
	end

	local cfg = Lua_CollectionBookConfigData.getConfig(self.data);
	if cfg == nil then
		self:setEnable(false);
		return;
	end

	local bagId = cfg.hero_id;
	local vo = DataCenter.collectionBookData:getCollectionBookVoById(bagId);
	if vo == nil or vo:checkActiveByCardId(self.data) ~= true then
		self:setEnable(false);
		return;
	end
	self:setEnable(true);
	
	local flashId = cfg.flash_id;
	local flashInfo = Lua_FlashCardConfigData.getConfig(flashId);
	self.flashItem:setData(flashInfo);
	self:updateDisplay(index, flashInfo.showNewCard);
	local bShowEffect = DataCenter.collectionBookUtil:checkShowEffectByCardId(flashId);
	self:showEffect(bShowEffect);
end

function Lua_CollectionWeaponEditItem:showEffect(bShow)
    if bShow then
        if self.effect == nil then
            self.effect = UICreate.createUIEffect(self.flashItem.content, "/effects/uiEffects/ui_scc_sk_0002", "ui_scc_sk_0002", 0, 0);
        end
        self.effect:setEnable(true);
    else
        if self.effect ~= nil then
            self.effect:setEnable(false);
        end
    end
end

function Lua_CollectionWeaponEditItem:onPressClick()
	if self.data > 0 then
		Lua_MsgUtil.callFunc("COLLECTBOOK_CANCEL_PAGECARD", self.index);
	end
end

function Lua_CollectionWeaponEditItem:dispose()
	if self.effect then
		self.effect:dispose();
		self.effect = nil;
	end
	if self.flashItem then
		self.flashItem:dispose();
		self.flashItem = nil;
	end
	self:superCall("dispose");
end