checkRequire("Lua_CollectionBookPageCardItem");
Lua_CollectionBookMainPanel = class("Lua_CollectionBookMainPanel", Lua_DisplayObject);
function Lua_CollectionBookMainPanel:ctor(p)
	self:superCall("ctor", p, "CollectionBookMainPanel_skin");
end

function Lua_CollectionBookMainPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.showPageCardCount = 4; -- 页面展示卡牌数量

	self:createTabBtnList();
	--勾选框
	self.selectedBox:setDir(0);
	self.selectedBox:addBoxChange(self, self.onSelectedBoxChange);

	self.tipsIcon:addClickFuntion(self, self.onClickTipsIcon); -- 提示Icon
	self.lastPageSp:addClickFuntion(self, self.onClickLastPageBtn); -- 上一页
	self.nextPageSp:addClickFuntion(self, self.onClickNextPageBtn); -- 下一页
end

function Lua_CollectionBookMainPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
end

function Lua_CollectionBookMainPanel:setSharePanel(isSharePanel)
	self.isSharePanel = isSharePanel;
	self:setPanelDisplay();
end

function Lua_CollectionBookMainPanel:dispose()
	self:endTimer();
	self.bagIds = nil;
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.tabBtnInfo ~= nil then
		self.tabBtnInfo:dispose();
		self.tabBtnInfo:clear();
		self.tabBtnInfo = nil;
	end
	if self.cardItemList ~= nil then
		for i = 1, #self.cardItemList do
			self.cardItemList[i]:dispose();
			self.cardItemList[i] = nil;
		end
		self.cardItemList = nil;
	end
	self:superCall("dispose");
end

function Lua_CollectionBookMainPanel:createTabBtnList()
	if self.btnList == nil then
		local font_size = 34;
		local hasContactCard = DataCenter.collectionBookUtil.hasContactCard;
		self.tabBtnInfo = Array();
		self.tabBtnInfo:add({ textStr = LanUtil.getValue(410013) });
		self.tabBtnInfo:add({ textStr = LanUtil.getValue(410014) });
		self.tabBtnInfo:add({ textStr = LanUtil.getValue(410015) });
		if hasContactCard then
			self.tabBtnInfo:add({ textStr = LanUtil.getValue(410016) });
			font_size = 28;
		end

		local widget = Mathf.Floor(680 / self.tabBtnInfo:getSize());
		local height = 62;
		self.btnList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
		self.btnList:setLocation(3, 154, 0);
		self.btnList:setButtonStyle("common_altas_1", "xui_common_button_005_n", "xui_common_button_004_n", widget, height);
		self.btnList:setButtonText(0, 0, "756150", "8f5123", font_size, font_size, Lua_MyUISettings.huakangFontName, UnityEngine.FontStyle.Normal);
		self.btnList:setButtonItem(widget, height);
		self.btnList:setClickCallBack(self, self.onBtnClick);
		self.btnList:setData(self.tabBtnInfo);
		self.btnList:setRectAnchor(7);
	end
end

function Lua_CollectionBookMainPanel:onClickTipsIcon()
	local tipsData = { des = LanUtil.getValue(410027), posX = 174, posY = -241 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_CollectionBookMainPanel:setPanelDisplay()
	local otherPlayerInfo = DataCenter.collectionBookData:getOtherPlayerInfo();
	if self.isSharePanel then
		self.tipsIcon:setEnable(false);
		self.activityNameSp:setEnable(false);
		self.playerNameBg:setEnable(true);
		self.activityNameTxt.text = nil;
		self.playerNameTxt.text = otherPlayerInfo.name;
	else
		self.tipsIcon:setEnable(true);
		self.activityNameSp:setEnable(true);
		self.playerNameBg:setEnable(false);
		self.activityNameTxt:setLangValue(410013);
		self.playerNameTxt.text = nil;

		self:addLuaEvent("UPDATE_CBCARDDETAIL_PUSHBOOK", self, self.updateCardList); -- 卡牌放入卡册更新
		self:addLuaEvent("UPDATE_CBCARDDETAIL_ACTIVECARD", self, self.updateCardList); -- 卡牌激活更新
		self:addLuaEvent("UPDATE_CBCARDDETAIL_UPDATECARD_REDPOINT", self, self.updateCardList); -- 卡牌红点数据更新
	end

	local selectedIndex, selectedTab = self:checkRedPointCard();
	self.firstCardListIndex = selectedIndex; 
	self.btnList:setSelected(selectedTab);
end

function Lua_CollectionBookMainPanel:onBtnClick(index)
	if self.selectedTab == index then
		return;
	end

	self.selectedTab = index;
	if self.cardIndex == nil then
		self.cardIndex = self.firstCardListIndex;
	else
		self.cardIndex = 1;
	end 
	self:updateCardList();
	self:controlTimer();
end

function Lua_CollectionBookMainPanel:checkRedPointCard()
	if self.isSharePanel then
		return 1, 1;
	end

	local type = 1;
	local selectedIndex = self:getRedPointCardIndexByType(type);
	if selectedIndex ~= nil then
		return selectedIndex, type;
	end

	type = 3;
	selectedIndex = self:getRedPointCardIndexByType(type);
	if selectedIndex ~= nil then
		return selectedIndex, type;
	end

	local hasContactCard = DataCenter.collectionBookUtil.hasContactCard;
	if hasContactCard then
		type = 4;
		selectedIndex = self:getRedPointCardIndexByType(type);
		if selectedIndex ~= nil then
			return selectedIndex, type;
		end
	end

	return 1, 1;
end

function Lua_CollectionBookMainPanel:getRedPointCardIndexByType(type)
	local bagIds = self:getBagIds(type, false);
	if bagIds == nil or #bagIds < 1 then
		return nil;
	end

	local vo;
	local bagId;
	for i = 1, #bagIds do
		bagId = bagIds[i];
		vo = DataCenter.collectionBookData:getCollectionBookVoById(bagId);
		if vo and vo:show_card_redpoint(vo.pushId) then
			local num = Mathf.Floor(i / self.showPageCardCount);
			local residueNum = i % self.showPageCardCount;
			if residueNum == 0 then
				num = num - 1;
			end
			local selectedIndex = num * self.showPageCardCount + 1;
			return selectedIndex;
		end
	end
	return nil;
end

function Lua_CollectionBookMainPanel:getBagIds(type, bShare)
	local ids;
	if type == 1 then
		if self.bSelected then
			ids = bShare ~= true and DataCenter.collectionBookData.activeWeaponBagIds or DataCenter.collectionBookData.otherActiveWeaponBagIds;
		else
			ids = DataCenter.collectionBookUtil.weaponBagIds;
		end
	elseif type == 2 then
		if self.bSelected then
			ids = bShare ~= true and DataCenter.collectionBookData.activeClassicBagIds or DataCenter.collectionBookData.otherActiveClassicBagIds;
		else
			ids = DataCenter.collectionBookUtil.classicBagIds;
		end
	elseif type == 3 then
		if self.bSelected then
			ids = bShare ~= true and DataCenter.collectionBookData.activeFrameBagIds or DataCenter.collectionBookData.otherActiveFrameBagIds;
		else
			ids = DataCenter.collectionBookUtil.frameBagIds;
		end
	elseif type == 4 then
		if self.bSelected then
			ids = bShare ~= true and DataCenter.collectionBookData.activeContactBagIds or DataCenter.collectionBookData.otherActiveContactBagIds;
		else
			ids = DataCenter.collectionBookUtil.contactBagIds;
		end
	end

	return ids;
end

function Lua_CollectionBookMainPanel:updateCardCountData()
	if self.isSharePanel then
		self:updateOtherCardCountData();
	else
		self:updateSelfCardCountData()
	end
end

function Lua_CollectionBookMainPanel:updateSelfCardCountData()
	local collectionBookData = DataCenter.collectionBookData;
	local collectionBookUtil = DataCenter.collectionBookUtil;
	if self.isClassicCard then
		self.curClassicNum = collectionBookData.activeClassicCardCount;
		self.tolClassicNum = self.bSelected and self.curClassicNum or collectionBookUtil.classicTCount;
	else
		if self.selectedTab == 1 then-- 神兵列传
			-- 普卡
			self.curComCardNum = collectionBookData.activeComCardWeaponCount;
			self.tolComCardNum = self.bSelected and self.curComCardNum or collectionBookUtil.weaponCTCount;

			-- 闪卡
			self.curFlaCardNum = collectionBookData.activeFlaCardWeaponCount;
			self.tolFlaCardNum = self.bSelected and collectionBookData.activeFlaCardWeaponTCount or collectionBookUtil.weaponFTCount;
		elseif self.selectedTab == 3 then -- 名人堂
			-- 普卡
			self.curComCardNum = collectionBookData.activeComCardFrameCount;
			self.tolComCardNum = self.bSelected and self.curComCardNum or collectionBookUtil.frameCTCount;
			-- 闪卡
			self.curFlaCardNum = collectionBookData.activeFlaCardFrameCount;
			self.tolFlaCardNum = self.bSelected and collectionBookData.activeFlaCardFrameTCount or collectionBookUtil.frameFTCount;
		elseif self.selectedTab == 4 then -- 联动卡
			-- 普卡
			self.curComCardNum = collectionBookData.activeComCardContactCount;
			self.tolComCardNum = self.bSelected and self.curComCardNum or collectionBookUtil.contactCTCount;
			-- 闪卡
			self.curFlaCardNum = collectionBookData.activeFlaCardContactCount;
			self.tolFlaCardNum = self.bSelected and collectionBookData.activeFlaCardContactTCount or collectionBookUtil.contactFTCount;
		end
	end
end

function Lua_CollectionBookMainPanel:updateOtherCardCountData()
	local collectionBookData = DataCenter.collectionBookData;
	local collectionBookUtil = DataCenter.collectionBookUtil;
	if self.isClassicCard then
		self.curClassicNum = collectionBookData.otherActiveClassicCardCount;
		self.tolClassicNum = self.bSelected and self.curClassicNum or collectionBookUtil.classicTCount;
	else
		if self.selectedTab == 1 then-- 神兵列传
			-- 普卡
			self.curComCardNum = collectionBookData.otherActiveComCardWeaponCount;
			self.tolComCardNum = self.bSelected and self.curComCardNum or collectionBookUtil.weaponCTCount;

			-- 闪卡
			self.curFlaCardNum = collectionBookData.otherActiveFlaCardWeaponCount;
			self.tolFlaCardNum = self.bSelected and collectionBookData.otherActiveFlaCardWeaponTCount or collectionBookUtil.weaponFTCount;
		elseif self.selectedTab == 3 then -- 名人堂
			-- 普卡
			self.curComCardNum = collectionBookData.otherActiveComCardFrameCount;
			self.tolComCardNum = self.bSelected and self.curComCardNum or collectionBookUtil.frameCTCount;
			-- 闪卡
			self.curFlaCardNum = collectionBookData.otherActiveFlaCardFrameCount;
			self.tolFlaCardNum = self.bSelected and collectionBookData.otherActiveFlaCardFrameTCount or collectionBookUtil.frameFTCount;
		elseif self.selectedTab == 4 then -- 联动卡
			-- 普卡
			self.curComCardNum = collectionBookData.otherActiveComCardContactCount;
			self.tolComCardNum = self.bSelected and self.curComCardNum or collectionBookUtil.contactCTCount;
			-- 闪卡
			self.curFlaCardNum = collectionBookData.otherActiveFlaCardContactCount;
			self.tolFlaCardNum = self.bSelected and collectionBookData.otherActiveFlaCardContactTCount or collectionBookUtil.contactFTCount;
		end
	end
end

function Lua_CollectionBookMainPanel:updateCardList()
	self.isClassicCard = self.selectedTab == 2;
	self:updateCardCountData();
	self.bagIds = self:getBagIds(self.selectedTab, self.isSharePanel) or {};
	self.bagCount = #self.bagIds;
	self:showNoneCard(self.bagCount == 0);
	self:updateCardItemList();
	self:updatePageNumTxt();
end

function Lua_CollectionBookMainPanel:showNoneCard(bShow)
	self.noneCardSp:setEnable(bShow);
	self.noneCardTxt:setEnable(bShow);
end

function Lua_CollectionBookMainPanel:updateCardItemList()
	local index;
	local bagId;
	local cardItem;
	for i = 1, self.showPageCardCount do
		index = self.cardIndex + (i - 1);
		bagId = self.bagIds[index];
		cardItem = self:getCardItem(i);
		if bagId ~= nil then
			cardItem:setData(bagId, i, self.isSharePanel, self.selectedTab == 2);
			cardItem:setEnable(true);
		else
			cardItem:setEnable(false);
		end
	end
end

function Lua_CollectionBookMainPanel:getCardItem(index)
	if self.cardItemList == nil then
		self.cardItemList = {};
	end

	local item = self.cardItemList[index];
	if item == nil then
		item = Lua_CollectionBookPageCardItem.new(self.content);
		self.cardItemList[index] = item;
	end

	return item;
end

function Lua_CollectionBookMainPanel:updatePageNumTxt()
	local num = Mathf.Ceil(self.cardIndex / self.showPageCardCount);
	local curPageNum = num == 0 and 1 or num;

	num = Mathf.Ceil(self.bagCount / self.showPageCardCount);
	local totalPageNum = num == 0 and 1 or num;
	self.pageNumTxt.text = LanUtil.formateStr(410024, curPageNum, totalPageNum);
end

function Lua_CollectionBookMainPanel:controlTimer()
	-- self.switchIndex = nil; --收集卡牌数量切换index
	if self.selectedTab == 2 then -- 页签index
		self:endTimer();
		self:showCollectCountTxt();
	else	
		self:endTimer();
		self:startTimer();
		self:showCollectCountTxt(true);
	end
end

-- 每2秒切换显示文本
function Lua_CollectionBookMainPanel:startTimer()
	if self.loopSwitch ~= true then
		self.loopSwitch = true;
		self:showCollectCountTxt();
		self:addTimer("CB_MAINPANEL_LOOPSWITCH_TXT", 2, self, self.showCollectCountTxt);
	end
end

function Lua_CollectionBookMainPanel:endTimer()
	if self.loopSwitch == true then
		self.loopSwitch = false;
		self:removeTimer(self, self.showCollectCountTxt);
	end
end

function Lua_CollectionBookMainPanel:showCollectCountTxt(isUpdateCount)
	local str;
	local curCount;
	local totalCount;
	if self.isClassicCard then
		str = LanUtil.getValue(410014);--"经典卡";
		curCount = self.curClassicNum;
		totalCount = self.tolClassicNum;
	else
		if isUpdateCount then
			self.switchIndex = nil;
		end
		self.switchIndex = self.switchIndex == nil and 0 or (self.switchIndex + 1) % 2;
		if self.switchIndex == 0 then
			str = LanUtil.getValue(410008);--"普卡";
			curCount = self.curComCardNum;
			totalCount = self.tolComCardNum;
		else
			str = LanUtil.getValue(410009);--"闪卡"
			curCount = self.curFlaCardNum;
			totalCount = self.tolFlaCardNum;
		end
	end
	self.collectCountTxt.text = LanUtil.formateStr(410010, str, curCount, totalCount);
end

function Lua_CollectionBookMainPanel:onSelectedBoxChange(val)
	self.bSelected = self.bSelected == nil and true or not self.bSelected;
	self.cardIndex = 1; 
	self:updateCardList();
	self:endTimer();
	self:startTimer();
	self:showCollectCountTxt();
end

function Lua_CollectionBookMainPanel:onClickLastPageBtn()
	local index = self.cardIndex - self.showPageCardCount;
	if index < 1 then
		OperateAlert.showLangValue(410025);
		return;
	end
	self.cardIndex = index;
	self:updateCardItemList();
	self:updatePageNumTxt();
end

function Lua_CollectionBookMainPanel:onClickNextPageBtn()
	local index = self.cardIndex + self.showPageCardCount;
	if index > self.bagCount then
		OperateAlert.showLangValue(410026);
		return;
	end

	self.cardIndex = index;
	self:updateCardItemList();
	self:updatePageNumTxt();
end