checkRequire("Lua_CommonFlashCardItem");
Lua_CollectionBookPageCardItem = class("Lua_CollectionBookPageCardItem", Lua_ListCell);
function Lua_CollectionBookPageCardItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_CollectionBookPageCardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.flashItem = Lua_CommonFlashCardItem.new(self.content);
	self.flashItem.canRotate = false; -- 是否可旋转
	self.flashItem:setSiblingIndex(0);
	self.flashItem:setCallBack(self, self.onPressClick);

	Lua_MsgUtil.addEventListener("PACK_ITEMS_UPDATE", self, self.onPackUpdate); -- 背包道具增加
    Lua_MsgUtil.addEventListener("MONEY_UPDATE", self, self.onPackUpdate); -- 货币增加
end

function Lua_CollectionBookPageCardItem:dispose()
	self.excharge_item = nil;
	if self.effect ~= nil then
		self.effect:dispose();
		self.effect = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	if self.flashItem ~= nil then
		self.flashItem:dispose();
		self.flashItem = nil;
	end
	self:superCall("dispose");
end

function Lua_CollectionBookPageCardItem:updateDisplayByIndex(index, bNewCard)
	local posX, posY, scale;
	if index == 1 then
		posX, posY = -176,  248;
	elseif index == 2 then
		posX, posY =  133,  248;
	elseif index == 3 then
		posX, posY = -176, -171;
	elseif index == 4 then
		posX, posY =  133, -171;
	end
	scale = bNewCard and 0.4 or 0.52;
	self:setLocation( posX, posY);
	self.flashItem:setScale(scale, scale);
end

function Lua_CollectionBookPageCardItem:setData(data, index, bShare, bClassic)
	self.data = data;
	self.index = index;
	self.showId = nil;
	self.bShare = bShare;
	self.bClassic = bClassic;
	self.bCompletionCard = nil;
	if self.data == nil then
		self.excharge_item = nil;
		return;
	end

	self:updateItem();
end

function Lua_CollectionBookPageCardItem:updateItem()
	self.excharge_item = nil;
	local vo = DataCenter.collectionBookData:getCollectionBookVoById(self.data);
	if vo == nil then
		return;
	end
	self.showId = nil;
	if self.bClassic then
		self.showId = vo.classic;
	else
		self.showId = self.bShare and vo.otherPushId or vo.pushId;
	end
	
	local cfg = Lua_CollectionBookConfigData.getConfig(self.showId);
	if cfg == nil then
		return;
	end

	local flashId = cfg.flash_id;
	local flashInfo = Lua_FlashCardConfigData.getConfig(flashId);
	self.flashItem:setData(flashInfo);
	self:updateDisplayByIndex(self.index, flashInfo.showNewCard);

	local bGray;
	local bShowEff;
	local bShowRedPoint;
	self.bCompletionCard = cfg.bCompletion;
	if self.bCompletionCard then
		if self.bShare then
			bGray = vo:checkOtherActiveByCardId(self.showId) ~= true;
		else
			bGray = vo:checkActiveByCardId(self.showId) ~= true;
			if bGray then
				self.excharge_item = cfg.change_item;
			end
		end
		bShowEff = DataCenter.collectionBookUtil:checkShowEffectByCardId(self.showId);
		bShowRedPoint = (not self.bShare) and vo.classic ~= self.showId and vo:show_card_redpoint(self.showId);
	else
		self.flashItem:showNocompleteCardState(true);
	end
	self.flashItem:setGray(bGray);
	self:showEffect(bShowEff);
	self:showRedDot(bShowRedPoint);
end

function Lua_CollectionBookPageCardItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(112, 177);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_CollectionBookPageCardItem:showEffect(bShow)
    if bShow then
        if self.effect == nil then
            self.effect = UICreate.createUIEffect(self.flashItem.content, "/effects/uiEffects/ui_scc_sk_0002", "ui_scc_sk_0002", 0, 0);
        end
        self.effect:setEnable(true);
    else
        if self.effect ~= nil then
            self.effect:setEnable(false);
        end
    end
end

function Lua_CollectionBookPageCardItem:onPressClick()
	if self.showId == nil then
		return;
	end
	
	if not self.bCompletionCard then
		OperateAlert.showLangValue(410033);
		return;
	end

	if self.bShare then
		Lua_WindowUtil.openWin("Lua_CollectionBookShareCardWindow", Lua_WinParam.ACTION_OPEN, tonumber(self.showId));
	else
		Lua_WindowUtil.openWin("Lua_CollectionBookCardDetailWindow", Lua_WinParam.ACTION_OPEN, tonumber(self.showId));
	end
end

function Lua_CollectionBookPageCardItem:onPackUpdate(dic)
	if self.excharge_item == nil or #self.excharge_item <= 0 or dic == nil then
		return;
	end

	local costId;
	local bChange;
	for i = 1, #self.excharge_item do
		costId = tonumber(self.excharge_item[i][1]);
		if dic[costId] then
			bChange = true;
			break;
		end
	end

	if not bChange then
		return;
	end

	self:updateItem();
end