checkRequire("Lua_CommonFlashCardItem");
Lua_NewCollectionBookShareCardWindow = class("Lua_NewCollectionBookShareCardWindow", Lua_Window);
function Lua_NewCollectionBookShareCardWindow:ctor()
	self:superCall("ctor");
	
	self.layer = MainWinDefine.NORMAL_TOP_LAYER;
	self.windowName = "Lua_NewCollectionBookShareCardWindow";
	self.skinName = "NewCollectionBookShareCard_skin";
	self.isFullSizeWin = true;
	self.showBlackMask = true;
	self.isClickClose = true;

	-- self.isShowFrontPage = true;
	-- self.setImgPath = "/images/common/ui_common_window_016.png";
    -- self:addPreLoadRes(self.setImgPath, Lua_LoadFileType.IMG);
end

function Lua_NewCollectionBookShareCardWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setLocation(-249, 503, 0);
	self.avatarItem:setScale(0.76, 0.76);
	self.avatarItem:setAvatarClick(self, self.onAvatarClick);
	self.avatarItem:setRectAnchor(4);

	self.flashItem = Lua_CommonFlashCardItem.new(self.content);
	self.flashItem:setLocation(0, 26);
	self.flashItem.openTime = 0.1;
	self.flashItem.rotateNum = 1;
	self.flashItem.canRotate = true;
end


function Lua_NewCollectionBookShareCardWindow:showWin(param)
	self:superCall("showWin", param);

	if type(param) == "table" then
		self.data = param.cardId;
		self.isOpenFromChat = param.isOpenFromChat;
	else
		self.data = param;
		self.isOpenFromChat = false;
	end
	
	local cfg = Lua_CollectionBookConfigData.getConfig(self.data);
	if cfg == nil then
		return;
	end

	local bagId = cfg.hero_id;
	local cBookVo = DataCenter.collectionBookData:getCollectionBookVoById(bagId);
	if cBookVo == nil then
		return;
	end

	self.bClassic = cBookVo.classic == self.data;

	local flashId = cfg.flash_id;
	local flashInfo = Lua_FlashCardConfigData.getConfig(flashId);
	self:setFlashCardPos(flashInfo);
	self.flashItem:setData(flashInfo);

	local time = cBookVo:getOtherCardTimeByCardId(self.data);
	local timeStr;
	if time and time > 1 then
		timeStr = LanUtil.formateStr(410055, Lua_TimeTransform.transSeconds25(time));
	end
	self.flashItem:setGray(timeStr == nil);
	self.timeTxt.text = timeStr == nil and LanUtil.getValue(410054) or timeStr;

	local palyerInfo = DataCenter.collectionBookData:getOtherPlayerInfo();
	if palyerInfo == nil then
		self.playerNameTxt.text = "";
		return;
	end
	self.playerId = palyerInfo.id;
	self.server_flag = palyerInfo.server_flag;
	self.playerNameTxt.text = palyerInfo.name;
	self.avatarItem:setRoleDressUp(palyerInfo.dress_info);
	self.avatarItem:setRoleLevel(palyerInfo.level);

	local bShowEffect = timeStr ~= nil and DataCenter.collectionBookUtil:checkShowEffectByCardId(self.data);
	self:showEffect(bShowEffect);
	self:showFlashProp();
end

-- 特效
function Lua_NewCollectionBookShareCardWindow:showEffect(bShow)
	if bShow then
        if self.effect == nil then
            self.effect = UICreate.createUIEffect(self.flashItem.frontPageObj, "/effects/uiEffects/ui_scc_sk_0001", "ui_scc_sk_0001", 21, -32);
        end
        self.effect:setEnable(true);
    else
        if self.effect ~= nil then
            self.effect:setEnable(false);
        end
    end
end

function Lua_NewCollectionBookShareCardWindow:setFlashCardPos(flashInfo)
	-- if not flashInfo.showNewCard then
	-- 	self.flashItem:setLocation(0, 79);
	-- 	self.nameBg:setLocation(4, 513);
	-- 	self.nameBg:setAltas("collect_book_atlas", "xui_scc_widget_24");
	-- 	self.nameBg:SetDimensions(494, 95);
	-- 	self.playerNameTxt:setLocation(-116, 523);
	-- 	self.timeTxt:setLocation(64, 485);
	-- 	self.avatarItem:setLocation(-196, 514, 0);
	-- end

	if self.bClassic then
		self.flashItem:setScale(1, 1);
		self.nameBg:setLocation(4, 452);
		self.nameBg:setAltas("collect_book_atlas", "xui_scc_widget_24");
		self.nameBg:SetDimensions(494, 95);
		self.playerNameTxt:setLocation(-116, 462);
		self.timeTxt:setLocation(64, 424);
		self.avatarItem:setLocation(-196, 453, 0);
	else
		self.flashItem:setScale(0.9, 0.9);
		self.avatarItem:setLocation(-249, 503, 0);
	end
end

function Lua_NewCollectionBookShareCardWindow:onAvatarClick()
	if self.playerId == nil then
		return;
	end

	if DataCenter.roleData:isMyself(self.playerId) then 
		OperateAlert.showLangValue(410023);
	else
		Lua_ProxyManager.getProxy("Lua_RoleProxy"):sOtherRoleId(self.playerId, self.server_flag);
	end
end

function Lua_NewCollectionBookShareCardWindow:resetShareData()
	if self.isOpenFromChat then
		DataCenter.collectionBookData:setOtherPlayerInfo(nil);
		DataCenter.collectionBookData:clearOtherSingleCard(self.data);
	end
end

function Lua_NewCollectionBookShareCardWindow:showFlashProp()
	local bShow = DataCenter.collectionBookUtil:checkShowEffectByCardId(self.data);
	if bShow then
		local cfg = Lua_CollectionBookConfigData.getConfig(self.data);
		local props = cfg.card_prop or {};
		self.attackDescTxt.text = LanUtil.formateStr(410079, props.attack);
		self.healthDescTxt.text = LanUtil.formateStr(410080, props.health);

	end
	self.flashPropObj:SetActive(bShow);
end

function Lua_NewCollectionBookShareCardWindow:dispose()
	if self.flashItem ~= nil then
		self.flashItem:dispose();
		self.flashItem = nil;
	end
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.effect ~= nil then
		self.effect:dispose();
		self.effect = nil;
	end
	self:resetShareData();
	self:superCall("dispose");
end